import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-sub-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-common-widget/vgk-common-widget.dart';

class VgkCardVerticalRangeWidget extends StatelessWidget {
  final AnimationController animationController;
  final Animation animation;
  final VgkCardHorizontaWithSubDetailModel data;
  final String primaryColor;
  final Function(VgkCardHorizontaWithSubDetailModel data) callBack;

  const VgkCardVerticalRangeWidget(
      {Key key,
      this.animationController,
      this.animation,
      this.data,
      this.callBack,
      this.primaryColor})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: new Matrix4.translationValues(
              0.0,
              30 * (1.0 - animation.value),
              0.0,
            ),
            child: InkWell(
              onTap: () {
                Navigator.push<dynamic>(
                  context,
                  MaterialPageRoute<dynamic>(
                    builder: (BuildContext context) => callBack(data),
                  ),
                );
              },
              child: Padding(
                padding: const EdgeInsets.only(
                  left: 16,
                  right: 16,
                  top: 8,
                  bottom: 8,
                ),
                child: Container(
                  decoration: BoxDecoration(
                    color: VgkProGamingTheme.white,
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(20.0),
                      bottomLeft: Radius.circular(20.0),
                      bottomRight: Radius.circular(20.0),
                      topRight: Radius.circular(20.0),
                    ),
                    boxShadow: <BoxShadow>[
                      BoxShadow(
                        color: VgkProGamingTheme.grey.withOpacity(0.2),
                        offset: Offset(1.1, 1.1),
                        blurRadius: 10.0,
                      ),
                    ],
                  ),
                  child: Column(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.all(16),
                        child: Row(
                          children: <Widget>[
                            Expanded(
                              child: Padding(
                                padding: EdgeInsets.only(
                                  right:
                                      VgkProGamingTheme.paddingDoubleExtraLarge,
                                ),
                                child: Column(
                                    children:
                                        rangeInfo(data.range, primaryColor)),
                              ),
                            ),
                            Center(
                              child: Stack(
                                children: <Widget>[
                                  Container(
                                    width: 100,
                                    height: 120,
                                    child: Column(
                                      mainAxisAlignment:
                                          MainAxisAlignment.center,
                                      crossAxisAlignment:
                                          CrossAxisAlignment.center,
                                      children: <Widget>[
                                        Padding(
                                          padding: EdgeInsets.all(8.0),
                                          child: CachedNetworkImage(
                                            imageUrl: data.src,
                                            progressIndicatorBuilder: (context,
                                                    url, downloadProgress) =>
                                                CircularProgressIndicator(
                                                    value: downloadProgress
                                                        .progress),
                                            errorWidget:
                                                (context, url, error) =>
                                                    Icon(Icons.error),
                                          ),
                                          // child: Image.network(data.src),
                                        ),
                                      ],
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  rangeInfo(List<VgkHeadModel> range, primaryColor) {
    var result = <Widget>[];
    range.forEach((element) {
      result.add(
        VgkCommonWidget.vgkRangeInfo(
            element.key,
            VgkProGamingTheme.intToStringConvertor(element.value),
            VgkProGamingTheme.stringToIntConvertor('100'),
            primaryColor),
      );
      result.add(SizedBox(
        height: 3,
      ));
    });
    return result;
  }
}
